package com.jiuqi.db;

package .tmp;

import com.jiuqi.db.DBResultSet;
import com.jiuqi.db.DBTrace;
import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.Array;
import java.sql.Blob;
import java.sql.Clob;
import java.sql.Connection;
import java.sql.Date;
import java.sql.ParameterMetaData;
import java.sql.PreparedStatement;
import java.sql.Ref;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Calendar;

public class DBPreparedStatement implements PreparedStatement {
  private PreparedStatement stmt;
  
  private Connection conn;
  
  public DBPreparedStatement(PreparedStatement aStmt, Connection aConn) {
    this.stmt = aStmt;
    this.conn = aConn;
    DBTrace.createConnection(this);
  }
  
  public ResultSet executeQuery(String string) throws SQLException {
    ResultSet rs = this.stmt.executeQuery(string);
    return (ResultSet)new DBResultSet(this, rs);
  }
  
  public int executeUpdate(String string) throws SQLException {
    return this.stmt.executeUpdate(string);
  }
  
  public void close() throws SQLException {
    this.stmt.close();
    DBTrace.closeConnection(this);
  }
  
  public int getMaxFieldSize() throws SQLException {
    return this.stmt.getMaxFieldSize();
  }
  
  public void setMaxFieldSize(int int0) throws SQLException {
    this.stmt.setMaxFieldSize(int0);
  }
  
  public int getMaxRows() throws SQLException {
    return this.stmt.getMaxRows();
  }
  
  public void setMaxRows(int int0) throws SQLException {
    this.stmt.setMaxRows(int0);
  }
  
  public void setEscapeProcessing(boolean boolean0) throws SQLException {
    this.stmt.setEscapeProcessing(boolean0);
  }
  
  public int getQueryTimeout() throws SQLException {
    return this.stmt.getQueryTimeout();
  }
  
  public void setQueryTimeout(int int0) throws SQLException {
    this.stmt.setQueryTimeout(int0);
  }
  
  public void cancel() throws SQLException {
    this.stmt.cancel();
  }
  
  public SQLWarning getWarnings() throws SQLException {
    return this.stmt.getWarnings();
  }
  
  public void clearWarnings() throws SQLException {
    this.stmt.clearWarnings();
  }
  
  public void setCursorName(String string) throws SQLException {
    this.stmt.setCursorName(string);
  }
  
  public boolean execute(String string) throws SQLException {
    return this.stmt.execute(string);
  }
  
  public ResultSet getResultSet() throws SQLException {
    return this.stmt.getResultSet();
  }
  
  public int getUpdateCount() throws SQLException {
    return this.stmt.getUpdateCount();
  }
  
  public boolean getMoreResults() throws SQLException {
    return this.stmt.getMoreResults();
  }
  
  public void setFetchDirection(int int0) throws SQLException {
    this.stmt.setFetchDirection(int0);
  }
  
  public int getFetchDirection() throws SQLException {
    return this.stmt.getFetchDirection();
  }
  
  public void setFetchSize(int int0) throws SQLException {
    this.stmt.setFetchSize(int0);
  }
  
  public int getFetchSize() throws SQLException {
    return this.stmt.getFetchSize();
  }
  
  public int getResultSetConcurrency() throws SQLException {
    return this.stmt.getResultSetConcurrency();
  }
  
  public int getResultSetType() throws SQLException {
    return this.stmt.getResultSetType();
  }
  
  public void addBatch(String string) throws SQLException {
    this.stmt.addBatch(string);
  }
  
  public void clearBatch() throws SQLException {
    this.stmt.clearBatch();
  }
  
  public int[] executeBatch() throws SQLException {
    return this.stmt.executeBatch();
  }
  
  public Connection getConnection() throws SQLException {
    return this.conn;
  }
  
  public ResultSet executeQuery() throws SQLException {
    ResultSet rs = this.stmt.executeQuery();
    return (ResultSet)new DBResultSet(this, rs);
  }
  
  public int executeUpdate() throws SQLException {
    return this.stmt.executeUpdate();
  }
  
  public void setNull(int int0, int int1) throws SQLException {
    this.stmt.setNull(int0, int1);
  }
  
  public void setBoolean(int int0, boolean boolean1) throws SQLException {
    this.stmt.setBoolean(int0, boolean1);
  }
  
  public void setByte(int int0, byte byte1) throws SQLException {
    this.stmt.setByte(int0, byte1);
  }
  
  public void setShort(int int0, short short1) throws SQLException {
    this.stmt.setShort(int0, short1);
  }
  
  public void setInt(int int0, int int1) throws SQLException {
    this.stmt.setInt(int0, int1);
  }
  
  public void setLong(int int0, long long1) throws SQLException {
    this.stmt.setLong(int0, long1);
  }
  
  public void setFloat(int int0, float float1) throws SQLException {
    this.stmt.setFloat(int0, float1);
  }
  
  public void setDouble(int int0, double double1) throws SQLException {
    this.stmt.setDouble(int0, double1);
  }
  
  public void setBigDecimal(int int0, BigDecimal bigDecimal) throws SQLException {
    this.stmt.setBigDecimal(int0, bigDecimal);
  }
  
  public void setString(int int0, String string) throws SQLException {
    this.stmt.setString(int0, string);
  }
  
  public void setBytes(int int0, byte[] byteArray) throws SQLException {
    byte[] bytes = (byteArray == null) ? new byte[0] : byteArray;
    try {
      InputStream stream = new ByteArrayInputStream(bytes);
      try {
        this.stmt.setBinaryStream(int0, stream, stream.available());
      } finally {
        stream.close();
      } 
    } catch (Exception ex) {
      throw new SQLException("写入流失败" + ex.getMessage());
    } 
  }
  
  public void setDate(int int0, Date date) throws SQLException {
    this.stmt.setDate(int0, date);
  }
  
  public void setTime(int int0, Time time) throws SQLException {
    this.stmt.setTime(int0, time);
  }
  
  public void setTimestamp(int int0, Timestamp timestamp) throws SQLException {
    this.stmt.setTimestamp(int0, timestamp);
  }
  
  public void setAsciiStream(int int0, InputStream inputStream, int int2) throws SQLException {
    this.stmt.setAsciiStream(int0, inputStream, int2);
  }
  
  public void setUnicodeStream(int int0, InputStream inputStream, int int2) throws SQLException {
    this.stmt.setUnicodeStream(int0, inputStream, int2);
  }
  
  public void setBinaryStream(int int0, InputStream inputStream, int int2) throws SQLException {
    this.stmt.setBinaryStream(int0, inputStream, int2);
  }
  
  public void clearParameters() throws SQLException {
    this.stmt.clearParameters();
  }
  
  public void setObject(int int0, Object object, int int2, int int3) throws SQLException {
    this.stmt.setObject(int0, object, int2, int3);
  }
  
  public void setObject(int int0, Object object, int int2) throws SQLException {
    this.stmt.setObject(int0, object, int2);
  }
  
  public void setObject(int int0, Object object) throws SQLException {
    if (object != null && object instanceof byte[]) {
      setBytes(int0, (byte[])object);
    } else {
      this.stmt.setObject(int0, object);
    } 
  }
  
  public boolean execute() throws SQLException {
    return this.stmt.execute();
  }
  
  public void addBatch() throws SQLException {
    this.stmt.addBatch();
  }
  
  public void setCharacterStream(int int0, Reader reader, int int2) throws SQLException {
    this.stmt.setCharacterStream(int0, reader, int2);
  }
  
  public void setRef(int int0, Ref ref) throws SQLException {
    this.stmt.setRef(int0, ref);
  }
  
  public void setBlob(int int0, Blob blob) throws SQLException {
    this.stmt.setBlob(int0, blob);
  }
  
  public void setClob(int int0, Clob clob) throws SQLException {
    this.stmt.setClob(int0, clob);
  }
  
  public void setArray(int int0, Array array) throws SQLException {
    this.stmt.setArray(int0, array);
  }
  
  public ResultSetMetaData getMetaData() throws SQLException {
    return this.stmt.getMetaData();
  }
  
  public void setDate(int int0, Date date, Calendar calendar) throws SQLException {
    this.stmt.setDate(int0, date, calendar);
  }
  
  public void setTime(int int0, Time time, Calendar calendar) throws SQLException {
    this.stmt.setTime(int0, time, calendar);
  }
  
  public void setTimestamp(int int0, Timestamp timestamp, Calendar calendar) throws SQLException {
    this.stmt.setTimestamp(int0, timestamp, calendar);
  }
  
  public void setNull(int int0, int int1, String string) throws SQLException {
    this.stmt.setNull(int0, int1, string);
  }
  
  public void setURL(int parameterIndex, URL x) throws SQLException {
    this.stmt.setURL(parameterIndex, x);
  }
  
  public boolean getMoreResults(int int0) throws SQLException {
    return this.stmt.getMoreResults(int0);
  }
  
  public ResultSet getGeneratedKeys() throws SQLException {
    return this.stmt.getGeneratedKeys();
  }
  
  public int executeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
    return this.stmt.executeUpdate(sql, autoGeneratedKeys);
  }
  
  public int executeUpdate(String sql, int[] columnIndexes) throws SQLException {
    return this.stmt.executeUpdate(sql, columnIndexes);
  }
  
  public int executeUpdate(String sql, String[] columnNames) throws SQLException {
    return this.stmt.executeUpdate(sql, columnNames);
  }
  
  public boolean execute(String sql, int autoGeneratedKeys) throws SQLException {
    return this.stmt.execute(sql, autoGeneratedKeys);
  }
  
  public boolean execute(String sql, int[] columnIndexes) throws SQLException {
    return this.stmt.execute(sql, columnIndexes);
  }
  
  public boolean execute(String sql, String[] columnNames) throws SQLException {
    return this.stmt.execute(sql, columnNames);
  }
  
  public int getResultSetHoldability() throws SQLException {
    return this.stmt.getResultSetHoldability();
  }
  
  public ParameterMetaData getParameterMetaData() throws SQLException {
    return this.stmt.getParameterMetaData();
  }
}
